==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/acl/lang/pl/lang.php <==
<?php
/**
 * polish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Grzegorz Żur <grzegorz.zur@gmail.com>
 */
$lang['admin_acl']             = 'Zarządzanie uprawnieniami';
$lang['acl_group']             = 'Grupa';
$lang['acl_user']              = 'Użytkownik';
$lang['acl_perms']             = 'Uprawnienia użytkownika';
$lang['page']                  = 'Strona';
$lang['namespace']             = 'Katalog';
$lang['btn_select']            = 'Wybierz';
$lang['p_user_id']             = 'Użytkownik <b class="acluser">%s</b> posiada następujące uprawnienia do strony <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Użytkownik <b class="acluser">%s</b> posiada następujące uprawnienia do katalogów <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Członkowie grupy <b class="aclgroup">%s</b> posiadają następujące uprawnienia do strony <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Członkowie grupy <b class="aclgroup">%s</b> posiadają następujące uprawnienia do strony <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Podaj <b>nazwę użytkownika lub grupy</b> w powyższym formularzu, by wyświetlić lub zmienić uprawnienia do strony <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Podaj <b>nazwę użytkownika lub grupy</b> w powyższym formularzu, by wyświetlić lub zmienić uprawnienia do katalogu <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Uwaga: Uprawnienia nie zostały nadane wprost ale są dziedziczone z grupy lub katalogu.';
$lang['p_isadmin']             = 'Uwaga: Wybrana grupa lub użytkownika zawsze dysponuje pełnymi uprawnieniami ponieważ posiada uprawnienia administratora.';
$lang['current']               = 'Aktywne reguły zarządzania uprawnieniami';
$lang['where']                 = 'Strona/Katalog';
$lang['who']                   = 'Użytkownik/Grupa';
$lang['perm']                  = 'Uprawnienie';
$lang['acl_perm0']             = 'Żadne';
$lang['acl_perm1']             = 'Czytanie';
$lang['acl_perm2']             = 'Zmiana';
$lang['acl_perm4']             = 'Tworzenie';
$lang['acl_perm8']             = 'Przesyłanie plików';
$lang['acl_perm16']            = 'Usuwanie';
$lang['acl_new']               = 'Dodaj nowy wpis';
$lang['acl_mod']               = 'Zmień wpis';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/pl/lang.php <==
<?php
/**
 * polish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Grzegorz Żur <grzegorz.zur@gmail.com>
 * @author Mariusz Kujawski <marinespl@gmail.com>
 * @author Maciej Kurczewski <pipijajko@gmail.com>
 */
$lang['admin_acl']             = 'Zarządzanie uprawnieniami';
$lang['acl_group']             = 'Grupa';
$lang['acl_user']              = 'Użytkownik';
$lang['acl_perms']             = 'Uprawnienia użytkownika';
$lang['page']                  = 'Strona';
$lang['namespace']             = 'Katalog';
$lang['btn_select']            = 'Wybierz';
$lang['p_user_id']             = 'Użytkownik <b class="acluser">%s</b> posiada następujące uprawnienia do strony <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Użytkownik <b class="acluser">%s</b> posiada następujące uprawnienia do katalogów <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Członkowie grupy <b class="aclgroup">%s</b> posiadają następujące uprawnienia do strony <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Członkowie grupy <b class="aclgroup">%s</b> posiadają następujące uprawnienia do strony <b class="aclns">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Podaj <b>nazwę użytkownika lub grupy</b> w powyższym formularzu, by wyświetlić lub zmienić uprawnienia do strony <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Podaj <b>nazwę użytkownika lub grupy</b> w powyższym formularzu, by wyświetlić lub zmienić uprawnienia do katalogu <b class="aclns">%s</b>.';
$lang['p_inherited']           = 'Uwaga: Uprawnienia nie zostały nadane wprost ale są dziedziczone z grupy lub katalogu.';
$lang['p_isadmin']             = 'Uwaga: Wybrana grupa lub użytkownika zawsze dysponuje pełnymi uprawnieniami ponieważ posiada uprawnienia administratora.';
$lang['p_include']             = 'Szersze uprawnienia zawierają węższe. Tworzenie, przesyłanie plików oraz usuwanie mają znaczenie tylko dla katalogów, nie dla stron.';
$lang['current']               = 'Aktywne reguły zarządzania uprawnieniami';
$lang['where']                 = 'Strona/Katalog';
$lang['who']                   = 'Użytkownik/Grupa';
$lang['perm']                  = 'Uprawnienie';
$lang['acl_perm0']             = 'Żadne';
$lang['acl_perm1']             = 'Czytanie';
$lang['acl_perm2']             = 'Zmiana';
$lang['acl_perm4']             = 'Tworzenie';
$lang['acl_perm8']             = 'Przesyłanie plików';
$lang['acl_perm16']            = 'Usuwanie';
$lang['acl_new']               = 'Dodaj nowy wpis';
$lang['acl_mod']               = 'Zmień wpis';
